import React, { useState, useEffect } from 'react';
import { Tree, Table, Space, message, Modal, Form, Input } from 'antd';
import {
  UsergroupAddOutlined,
  FileAddTwoTone,
  FolderAddTwoTone,
  EditTwoTone,
  DeleteTwoTone,
} from '@ant-design/icons';
import { PageContainer } from '@ant-design/pro-layout';
// import classnames from 'classnames';
import { get } from '../../services';
import styles from './UserManage.less';

const UserManage = () => {
  const time = new Date();
  const [tableLoading, setTableLoading] = useState(false);
  const [treeData, setTreeData] = useState([]); // 用户机构树
  const [tableData, setTableData] = useState([]); // 用户表
  const [userVisible, setUserVisible] = useState(false);
  const [deleteUserVisible, setDeleteUserVisible] = useState(false);
  const [orgTitle, setOrgTitle] = useState('机构');
  const [orgID, setOrgID] = useState();
  const [userID, setUserID] = useState('机构');
  const [addUserForm] = Form.useForm();
  // 渲染机构目录树
  const mapTree = org => {
    const haveChildren = Array.isArray(org.children) && org.children.length > 0;
    return {
      title: (
        <div className={styles.iconWraper1}>
          {org.text}
          <FileAddTwoTone
            onClick={e => addUser(e, org.text, org.id)}
            title="添加用户"
          />
          <FolderAddTwoTone onClick={addSubOrg} title="添加下级机构" />
          <EditTwoTone onClick={editOrg} title="编辑" />
          <DeleteTwoTone onClick={deleteOrg} title="删除" />
        </div>
      ),
      key: org.id,
      // icon: <CaretDownOutlined />,
      // 判断它是否存在子集，若果存在就进行再次进行遍历操作，知道不存在子集便对其他的元素进行操作
      children: haveChildren ? org.children.map(i => mapTree(i)) : [],
    };
  };
  // 用户表列名
  const columns = [
    {
      title: '登录名',
      dataIndex: 'loginName',
      key: 'loginName',
    },
    {
      title: '用户姓名',
      dataIndex: 'userName',
      key: 'userName',
    },
    {
      title: '手机号码',
      dataIndex: 'phone',
      key: 'phone',
    },
    {
      title: '钉钉账户',
      dataIndex: 'ddid',
      key: 'ddid',
    },
    {
      title: '微信账户',
      dataIndex: 'wxid',
      key: 'wxid',
    },
    {
      title: '操作',
      key: 'action',
      render: (text, record) => (
        <Space size="middle">
          <a>关联角色 {record.name}</a>
          <a>更改机构</a>
          <a>编辑</a>
          <a>冻结</a>
          <a onClick={() => deleteUser(record)}>删除</a>
        </Space>
      ),
    },
  ];

  // 获取用户机构列表
  useEffect(() => {
    setTableLoading(true);
    get(`/Cityinterface/rest/services/OMS.svc/U_GetOUTree`, {
      _version: 9999,
      _dc: time.getTime(),
      node: -1,
    })
      .then(res => {
        setTableLoading(false);
        if (res.length > 0) {
          const orgTree = res.map(org => mapTree(org));
          setTreeData(orgTree);
        }
      })
      .catch(err => {
        setTableLoading(false);
        message.error(err);
      });
  }, []);

  // 获取当前机构下所有用户
  const onSelect = props => {
    setTableLoading(true);
    get(`/Cityinterface/rest/services/OMS.svc/U_GetOneOUUserListNew`, {
      _version: 9999,
      _dc: time.getTime(),
      OUID: props[0],
    })
      .then(res => {
        setTableLoading(false);
        if (res.root.length > 0) {
          const table = res.root.map((item, index) => {
            item.key = index;
            return item;
          });
          setTableData(table);
        }
      })
      .catch(err => {
        setTableLoading(false);
        message.error(err);
      });
  };

  const addUser = (e, title, id) => {
    e.stopPropagation();
    setUserVisible(true);
    setOrgTitle(`在${title}下添加用户`);
    setOrgID(id);
  };
  const addSubOrg = (e, title, id) => {
    e.stopPropagation();
    // setUserVisible(true);
    // setOrgTitle(`在${title}下添加机构`);
    setOrgID(id);
  };
  const editOrg = (e, title, id) => {
    e.stopPropagation();
    // setUserVisible(true);
    // setOrgTitle(`在${title}下添加用户`);
    setOrgID(id);
  };
  const deleteOrg = (e, title, id) => {
    e.stopPropagation();
    // setUserVisible(true);
    // setOrgTitle(`在${title}下添加用户`);
    setOrgID(id);
  };
  // 提交-添加用户
  const submitAddUser = () => {
    get(`/Cityinterface/rest/services/OMS.svc/U_AddUser`, {
      _version: 9999,
      _dc: time.getTime(),
      OUID: orgID,
      loginName: addUserForm.getFieldValue('loginName'),
      password: addUserForm.getFieldValue('password'),
      userName: addUserForm.getFieldValue('userName'),
      phone: addUserForm.getFieldValue('phone') || '',
      email: addUserForm.getFieldValue('email') || '',
      ddid: addUserForm.getFieldValue('ddid') || '',
      wxid: addUserForm.getFieldValue('wxid') || '',
    })
      .then(res => {
        if (res.message === '') {
          Modal.success({
            content: '添加成功',
          });
          setUserVisible(false);
          // 重新获取用户表
          onSelect([orgID]);
        } else {
          Modal.error({
            title: '添加失败',
            content: res.message,
          });
        }
      })
      .catch(err => {
        message.error(err);
      });
  };

  const deleteUser = record => {
    setDeleteUserVisible(true);
    setUserID(record.userID);
  };
  const submitDeleteUser = () => {
    get(`/Cityinterface/rest/services/OMS.svc/U_DeleteUser`, {
      _version: 9999,
      _dc: time.getTime(),
      userID,
    })
      .then(res => {
        if (res.message === '') {
          Modal.success({
            content: '删除成功',
          });
          setDeleteUserVisible(false);
          // 重新获取用户表
          onSelect([orgID]);
        } else {
          Modal.error({
            title: '删除失败',
            content: res.message,
          });
        }
      })
      .catch(err => {
        setTableLoading(false);
        message.error(err);
      });
  };

  return (
    <PageContainer>
      <div
        style={{
          width: '20%',
          height: 'calc(100vh - 194px)',
          background: 'white',
          float: 'left',
          padding: '10px',
        }}
      >
        <div style={{ padding: '8px' }}>
          机构列表
          <UsergroupAddOutlined style={{ color: '#1890ff', float: 'right' }} />
        </div>
        <Tree
          showLine="true"
          showIcon="true"
          loading={tableLoading}
          onSelect={onSelect}
          treeData={treeData}
        />
      </div>
      <div
        style={{
          width: '79%',
          height: 'calc(100vh - 194px)',
          background: 'white',
          float: 'right',
          padding: '20px',
        }}
      >
        <Table
          columns={columns}
          dataSource={tableData}
          loading={tableLoading}
        />
      </div>
      <Modal
        title={orgTitle}
        visible={userVisible}
        onOk={submitAddUser}
        onCancel={() => setUserVisible(false)}
        okText="确认"
        cancelText="取消"
      >
        {/* <div style={{ width: '20%', float: 'left' }}>
          <UserAddOutlined style={{ color: 'blue', width: '40px' }} />
        </div> */}
        {/* <div style={{ width: '80%', float: 'right' }}> */}
        <Form form={addUserForm}>
          <Form.Item
            name="loginName"
            label="登录名称"
            rules={[
              {
                required: true,
              },
            ]}
          >
            <Input />
          </Form.Item>
          <Form.Item
            name="password"
            label="账户密码"
            rules={[
              {
                required: true,
              },
            ]}
          >
            <Input />
          </Form.Item>
          <Form.Item
            name="userName"
            label="用户名称"
            rules={[
              {
                required: true,
              },
            ]}
          >
            <Input />
          </Form.Item>
          <Form.Item name="phone" label="手 机 号 码">
            <Input />
          </Form.Item>
          <Form.Item name="email" label="电 子 邮 件">
            <Input />
          </Form.Item>
          <Form.Item name="ddid" label="钉 钉 账 户">
            <Input />
          </Form.Item>
          <Form.Item name="wxid" label="微 信 账 户">
            <Input />
          </Form.Item>
        </Form>
        {/* </div> */}
      </Modal>
      <Modal
        title="删除用户"
        visible={deleteUserVisible}
        onOk={submitDeleteUser}
        onCancel={() => setDeleteUserVisible(false)}
        okText="确认"
        cancelText="取消"
      >
        <p>即将关联删除 主站点 用户关系，是否确认删除？</p>
      </Modal>
    </PageContainer>
  );
};

export default UserManage;
